#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://imagination.sourceforge.net/
# source location    : http://freefr.dl.sourceforge.net/sourceforge/imagination/imagination-3.0.tar.gz
# last revised       : 29.04.2011
# dependency         : ffmpeg

softname='imagination'
softversion='3.0'
packageversion='72.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://freefr.dl.sourceforge.net/sourceforge/$softname/$softname-$softversion.tar.gz

#  prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
           |-----handy-ruler------------------------------------------------------|
imagination: imagination - A DVD-slideshow application
imagination:
imagination: It allows you to create a slideshow of pictures to be viewed on a
imagination: home DVD player.
imagination: 
imagination:
imagination:
imagination:
imagination:
imagination: 
imagination:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make 
make install DESTDIR=$dest

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion

#cat << "EOF" > $dest/install/doinst.sh
# Create missing link to libtool
#if [ -x usr/lib/libltdl.so.3 ]; then
#   echo "Lidltdl.so.3 is present"  
#else
#   echo "Creating libltdl.so.3"
#   ln -s /usr/lib/libltdl.so.7 /usr/lib/libltdl.so.3
#fi
#EOF
	
# strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "alsa-lib,atk,cairo,expat,file,flac,fontconfig,freetype,\
gcc,glib2,gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,\
libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libao,libid3tag,libmad,libogg,libpng,libtool,libvorbis,libxcb,pango,\
pixman,sox,wavpack,xcb-util,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/imagination/source/build-imagination.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
